import { EditorInterface, NodeInterface } from '@aomao/engine';
import './index.css';
export declare type Status = 'uploading' | 'done' | 'error';
export declare type Size = {
    width: number;
    height: number;
    naturalWidth: number;
    naturalHeight: number;
};
export declare type Options = {
    /**
     * 卡片根节点
     */
    root: NodeInterface;
    /**
     * 容器
     */
    container: NodeInterface;
    /**
     * 状态
     * uploading 上传中
     * done 上传完成
     * error 错误
     */
    status: Status;
    /**
     * 图标链接
     */
    src: string;
    /**
     * 标题
     */
    alt?: string;
    /**
     * 链接
     */
    link?: {
        href: string;
        target?: string;
    };
    /**
     * 错误消息
     */
    message?: string;
    /**
     * 样式名称，多个以空格隔空
     */
    className?: string;
    /**
     * 图片大小
     */
    size?: Size;
    /**
     * 上传进度
     */
    percent?: number;
    /**
     * 图片渲染前调用
     * @param status 状态
     * @param src 图片地址
     * @returns 图片地址
     */
    onBeforeRender?: (status: 'uploading' | 'done', src: string) => string;
    onChange?: (size?: Size) => void;
    onError?: () => void;
};
export declare const winPixelRatio: number;
declare class Image {
    private editor;
    private options;
    private root;
    private progress;
    private image;
    private detail;
    private meta;
    private maximize;
    private resizer?;
    private pswp;
    src: string;
    status: Status;
    size: Size;
    maxWidth: number;
    rate: number;
    constructor(editor: EditorInterface, options: Options);
    renderTemplate(message?: string): string;
    bindErrorEvent(node: NodeInterface): void;
    setProgressPercent(percent: number): void;
    imageLoadCallback(): void;
    onWindowResize: () => void;
    imageLoadError(): void;
    getMaxWidth(node?: NodeInterface): number;
    /**
     * 重置大小
     */
    resetSize(): void;
    changeSize(width: number, height: number): void;
    isSvg(): boolean;
    openZoom(event: MouseEvent): void;
    closeZoom(): void;
    renderEditor(): void;
    destroyEditor(): void;
    destroy(): void;
    focus: () => void;
    blur: () => void;
    render(): void;
}
export default Image;
