import { Card, CardToolbarItemOptions, CardType, NodeInterface, ToolbarItemOptions } from '@aomao/engine';
import { Size } from './image';
export declare type ImageValue = {
    /**
     *  图片地址
     */
    src: string;
    /**
     * 位置
     */
    align?: string;
    /**
     * 状态
     * uploading 上传中
     * done 上传成功
     */
    status?: 'uploading' | 'done' | 'error';
    /**
     * 标题
     */
    alt?: string;
    /**
     * 链接
     */
    link?: {
        href: string;
        target?: string;
    };
    /**
     * 上传进度
     */
    percent?: number;
    /**
     * 错误状态下的错误信息
     */
    message?: string;
    /**
     * 图片大小
     */
    size?: {
        /**
         * 图片展示宽度
         */
        width: number;
        /**
         * 图片展示高度
         */
        height: number;
        /**
         * 图片真实宽度
         */
        naturalWidth: number;
        /**
         * 图片真实高度
         */
        naturalHeight: number;
    };
};
declare class ImageComponent extends Card<ImageValue> {
    private image?;
    private widthInput?;
    private heightInput?;
    private isLocalError?;
    static get cardName(): string;
    static get cardType(): CardType;
    /**
     * 设置上传进度
     * @param percent 进度百分比
     */
    setProgressPercent(percent: number): void;
    setSize(size: Size): void;
    onInputChange(width: string | number, height: string | number): void;
    toolbar(): Array<CardToolbarItemOptions | ToolbarItemOptions>;
    onSelect(selected: boolean): void;
    onActivate(activated: boolean): void;
    render(): string | void | NodeInterface;
    didUpdate(): void;
}
export default ImageComponent;
