import { File, NodeInterface, Plugin, SchemaInterface } from '@aomao/engine';
import ImageComponent from './component';
export declare type Options = {
    /**
     * 文件上传配置
     */
    file: {
        /**
         * 文件上传地址
         */
        action: string;
        /**
         * 数据返回类型，默认 json
         */
        type?: '*' | 'json' | 'xml' | 'html' | 'text' | 'js';
        /**
         * 额外携带数据上传
         */
        data?: {};
        /**
         * 请求类型，默认 multipart/form-data;
         */
        contentType?: string;
        /**
         * 图片接收的格式，默认 "svg","png","bmp","jpg","jpeg","gif","tif","tiff","emf","webp"
         */
        accept?: string | Array<string>;
        /**
         * 文件选择限制数量
         */
        multiple?: boolean | number;
        /**
         * 上传大小限制，默认 1024 * 1024 * 5 就是5M
         */
        limitSize?: number;
    };
    remote: {
        /**
         * 上传地址
         */
        action: string;
        /**
         * 数据返回类型，默认 json
         */
        type?: '*' | 'json' | 'xml' | 'html' | 'text' | 'js';
        /**
         * 额外携带数据上传
         */
        data?: {};
        /**
         * 请求类型，默认 multipart/form-data;
         */
        contentType?: string;
    };
    /**
     * Markdown
     */
    markdown?: boolean;
    /**
     * 解析上传后的Respone，返回 result:是否成功，data:成功：图片地址，失败：错误信息
     */
    parse?: (response: any) => {
        result: boolean;
        data: string;
    };
    /**
     * 是否是第三方图片地址，如果是，那么地址将上传服务器下载图片
     */
    isRemote?: (src: string) => boolean;
};
export default class extends Plugin<Options> {
    private cardComponents;
    private loadCounts;
    static get pluginName(): string;
    private extensionNames;
    init(): void;
    isImage(file: File): boolean;
    dataURIToFile(dataURI: string): Blob;
    loadImage(id: string, value: {
        src: string;
        status: string;
    }): void;
    waiting(): Promise<void>;
    execute(files?: Array<File> | string | MouseEvent): Promise<void>;
    dropFiles(files: Array<File>): false | undefined;
    pasteSchema(schema: SchemaInterface): void;
    pasteFiles(files: Array<File>): false | undefined;
    pasteEach(node: NodeInterface): void;
    uploadAddress(src: string, component: ImageComponent): void;
    insertRemote(src: string, alt?: string): void;
    pasteAfter(): void;
    markdown(event: KeyboardEvent): void;
    pasteMarkdown(node: NodeInterface): void;
}
